*==============================================================
* Rival Growth Prospects & Equity Prices: Evidence from Layoffs
*==============================================================

* Authors: Bordeman, Kannan, Pinheiro
* Objective: Set up layoff data for running a short run event study on Placebo Events
* Data Sources: Compustat, Hoberg Phillips' TNIC classification, Factiva   

*==============================================================
* 1. SHORT RUN EVENT STUDY SET-UP FOR 3 DIGIT SIC COMPETITORS 
*==============================================================

clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data/placebo files"
/*This command allows me to access .dta files in my personal folder.  If need be
change to the desired directory*/

*==============================================================
* PREPARING FOR ANALYSIS
*==============================================================

use placebo_announcers_readyforstep2.dta, clear
/*This imports our file with a placebo date for all our announcers in our final sample*/

sort gvkey
*This sorts by gvkey

merge m:1 gvkey fyear using compustat_data, keep (match master using)
rename _merge merge_compustat_data
drop if cusip == ""

keep conm cusip gvkey announcer sic sic_1dig sic_2dig sic_3dig placebo_date fyear
rename placebo_date layoff_date

*==============================================================
* FOR EACH PLACEBO ANNOUNCER, CREATE A GROUP OF RIVALS BASED ON SIC3
*==============================================================

* Changing string values to a numeric value
destring sic_3dig, replace 
destring sic_2dig, replace 
sort sic_2dig (fyear)
destring sic, gen(sic_num)

* Creating an indicator variable for each SIC and fyear cobo
egen si=group(sic_3dig fyear)

* Creating an indicator to see which si groups have a layoff. Drop groups with no layoff 
bysort si: egen avdate=mean(layoff_date)
drop if avdate==.
drop avdate

/* Creating a counting variable to determine how many copies of rival
observations we need.  We may have more than one layoff in a particular
si group, so we will need to make copies of all the firms*/
by si: egen counter=count(layoff_date)
sort si (fyear layoff_date)
tab si
tab counter
by si: gen layoff_counter=_n if layoff_date!=.

levelsof layoff_counter, local(levels)
foreach y of local levels {
gen layoff_date`y'=layoff_date if layoff_counter==`y'
}

* We want to add the corresponding layoff_date info for all rivals in a group below a particular layoff_date
levelsof layoff_counter, local(levels)
foreach y of local levels{
by si: replace layoff_date`y'=layoff_date`y'[_n-1] if missing(layoff_date`y')
}

* We want to add the corresponding layoff_date info for all variables above a particular layoff_date
levelsof layoff_counter, local(levels)
foreach y of local levels{
by si: replace layoff_date`y'=layoff_date`y'[_n+`y'] if missing(layoff_date`y')
}

*This generates a unique identifier for each observation
gen totalcount=_n

/*This should now stack all of our layoff dates into a single column
and should create copies of observations that are associated with more than one 
layoff date. */
rename layoff_date announce_date
reshape long layoff_date, i(totalcount) j(layoff_number)

drop if layoff_date==.
*101317 observations deleted

* GENERATING COMPETITOR GROUP FOR EACH LAYOFF
sort si (layoff_date announce_date)
replace announcer=0
replace announcer=1 if announce_date==layoff_date & layoff_counter==layoff_number
egen si1=group(sic_3dig layoff_date layoff_number)

* DROPPING SI1 WHERE MULTIPLE LAYOFFS OCCUR ON SAME DAY 
codebook announcer
sort si1 announcer
by si1: egen x = sum(announcer)
codebook x
drop if x>1 & x!=.
drop x

* DROPPING DUPLICATES WITHIN AN SI1 CLUSTER
gsort si1 -announcer
duplicates report si1 gvkey
duplicates drop si1 gvkey, force

* ENTER LAYOFF DATE & SIZE FOR COMPETITORS
gsort si1 -announcer
by si1: gen si1_count=_n
by si1: replace announce_date=announce_date[_n-1] if si1_count!=1

drop if announce_date==.
 *0 observations dropped
  
*==============================================================
* GENERATING REQUEST FILE TO RETRIEVE PLACEBO EVENT STUDY RESULTS FROM
* EVENTUS ON WRDS
*==============================================================
gen cusip_8dig= substr(cusip,1,8)
drop if cusip_8dig==""
order cusip_8dig, before(announce_date)
format announce_date %tdCCYYNNDD
saveold reshaped_layoff_data_sic3dig_placebo, replace


keep cusip_8dig announce_date
 sort cusip_8dig announce_date
export delimited using placebo_eventus_input.txt, delimiter(tab) novarnames replace


