*==============================================================
* Rival Growth Prospects & Equity Prices: Evidence from Layoffs
*==============================================================

* Authors: Bordeman, Kannan, Pinheiro
* Objective: Generating necessary event study variables for Placebo events
* Data Sources: Compustat, CRSP, Eventus, Hoberg Phillips' TNIC classification, Factiva 
*==============================================================
* SET UP
*==============================================================
clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data/placebo files"
/*This command allows me to access .dta files in my personal folder.  If need be
change to the desired directory*/

use reshaped_layoff_data_sic3dig_placebo.dta, clear

*==============================================================
* ALERT: DUPLICATES CHECK WITHIN AN SI1 CLUSTER
*==============================================================
gsort si1 -announcer
duplicates report si1 gvkey
duplicates drop si1 gvkey, force

*==============================================================
* Merge Winsorized Compustat Data
*==============================================================
destring sic, replace
merge m:1 gvkey fyear using compustat_data, keep (match)
rename _merge comp_merge
gsort si1-announcer
*matched all

drop  tic fyr totalcount comp_merge

*==============================================================
* Merge Eventus
*==============================================================
compress
merge m:1 cusip_8dig announce_date using eventus_MAR_sic_placebo, keep (match master)
rename _merge merge_eventus_placebo
*At this point, we matched 33,045 observations. Not matched 10,942 from master
drop if car_window_1==.

* Dropped 10,992

*=================================================================
* VARIABLE CREATION
*=================================================================

*1. Good & Bad News Indicators
	gen positive_car_window_1 =.
	 replace positive_car_window_1 =1 if car_window_1>0
	 replace positive_car_window_1=0 if car_window_1<=0
	gen positive_CAR_announcer_ann=.
	 replace positive_CAR_announcer_ann=1 if positive_car_window_1 ==1 & announcer==1
	 replace positive_CAR_announcer_ann=0 if positive_car_window_1 ==0 & announcer==1
	gsort si1 -announcer
	by si1: replace positive_CAR_announcer_ann=positive_CAR_announcer_ann[_n-1] if announcer==0

*2. Hirschman-herfindahl index
*A. This is for all firms in an industry with valid sales data
	bysort si1: egen total_sales = sum(win_lag_CPI_sale)
	gen market_share = win_lag_CPI_sale/total_sales
	egen mkt_share_group = pctile(market_share), by(si1) p(95) 
	gen market_share_2=market_share^2
	by si1: egen lag_HHI=sum(market_share_2)
	drop total_sales market_share market_share_2
	winsor lag_HHI, p(0.01) gen(win_lag_HHI)


*3. Time Indicators
	gen yearann = year(announce_date)
	label var yearann "year of announcement"
	gen decade=.
	 replace decade=1 if yearann>=1980 & yearann<1990
	 replace decade=2 if yearann>=1990 & yearann<2000
	 replace decade=3 if yearann>=2000
	gen decade2=0
	 replace decade2=1 if decade==2
	gen decade3=0
     replace decade3 = 1 if decade==3
    tab decade
		

*4. Variables related to Event Study

*A. Assigning announcer CAR to all competitors within si1
	gsort si1-announcer
	by si1: gen announcer_car_window_1=car_window_1 if announcer==1
	by si1: replace announcer_car_window_1=announcer_car_window_1[_n-1] if announcer!=1	

*B. Assigning positive announcer CAR dummy to all competitors within si1
	bysort si1: egen positive_CAR_announcer=max(positive_CAR_announcer_ann)
	label var positive_CAR_announcer "Positive Announcer 3-day CAR, Indicator Variable"
	sum car_window_1 if announcer==0, detail
	sum car_window_1 if announcer==1, detail

*C. Revising variable definition that describes R&D expenditure
	
	gen win_lag_rd_complete = win_lag_rd
	 replace win_lag_rd_complete = 0 if win_lag_rd == .
	gen missing_rd = 0
	replace missing_rd = 1 if win_lag_rd == .
	label var missing_rd "No R\&D data"

*5. Segment data variables
	bysort si1: gen announcer_nseg1=nseg if announcer==1
	bysort si1: egen announcer_nseg=max(announcer_nseg1)
	gen dist_ann_nseg=nseg-announcer_nseg
	 drop announcer_nseg1
	 label var dist_ann_nseg "# of segments relative to announcer"
	gen abs_dist_ann_nseg = abs(dist_ann_nseg)

drop if si1==.
   

/*Here we want to drop the si1 clusters that don't have any announcers. This 
  problem is is created when we lose announcers due to non matching */
gsort si1-announcer
by si1: egen sum_announcer = sum(announcer)
drop if sum_announcer!=1
drop sum_announcer
gsort si1-announcer


*==============================================================
* Labeling key variables
*==============================================================

label var win_lag_liquidity "Liquidity, winsorized and lagged"
label var win_lag_Q "Q, winsorized and lagged Kaplan Zingales"
label var win_lag_CPI_sale "Sales, winsorized and lagged"
label var win_lag_leverage "Leverage, winsorized and lagged"
label var win_lag_ROA "ROA, winsorized and lagged"
label var win_lag_KZ "Kaplan Zingales Index, winsorized and lagged"
label var win_lag_SA "Size/Age Index, winsorized and lagged"
label var win_lag_WW "Whited Wu Index, winsorized and lagged"


 
 saveold ready_for_analysis_placebo, replace


