*==============================================================
* Rival Growth Prospects & Equity Prices: Evidence from Layoffs
*==============================================================

* Authors: Bordeman, Kannan, Pinheiro
* Objective: Construct variables to describe firm characteristics
* Data Sources: Compustat, Hoberg Phillips' TNIC classification   

*==============================================================
* SET UP
*==============================================================

clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"
*This command allows me to access .dta files in my personal folder.


*==============================================================
* LOADING RAW COMPUSTAT DATA
*==============================================================

use compustat_data_raw
drop if fyear<1979 
drop if fyear>2010
 * 329,683 observations after excluding pre 1979 and post 2010 firms


*==============================================================
* Cut 1: We want only US firms
*==============================================================
drop if fic!="USA"
codebook gvkey
 *We are dropping all foreign firms not incorporated in the USA.
 *we drop 52,410 observations. We are left with 277,273 observations and 25, 992 unique firms


*==============================================================
* Cut 2: Industries
*==============================================================
gen sic_4dig = sic
gen sic_3dig=substr(sic,1,3)
gen sic_2dig=substr(sic,1,2)
gen sic_1dig=substr(sic,1,1)
	
destring sic_3dig, replace
destring sic_2dig, replace
destring sic_1dig, replace
destring sic, replace

drop if sic<=6799 & sic>=6000
 *dropping financial firms. we drop 64,999 observations after excluding pre 1979 and post 2010 firms
 codebook gvkey
 *we are left with 212,274 observations and 19,326 unique firms

drop if sic>=4610 & sic<=4991 
codebook gvkey
 *dropping utilities firms. we drop 21,738 and are left with 190,536 observations and 17,695 unique firms

drop if sic_3dig==999
codebook gvkey
 *dropping nothing firms. we drop 3,884 and are left with 186,652 observations and 17,337 unique firms
 

*==============================================================
* Cut 3: Raw Compustat Data
*==============================================================
drop if at==.
 *Dropped 14,074 observations
drop if at<=1
 *Dropped 8,134 observations
drop if sale==.
 *Dropped 600 observations
drop if sale<1
 *Dropped 10,372 observations
drop if seq<0
 *Dropped 10,785 observations
drop if emp==. 
 *Dropped 8,622 observations
drop if emp<=0
 *Dropped 679 observations
codebook gvkey
 *We are left with 133,386 observations and 14,451 unique firms

*==============================================================
* PANEL DATA SETUP
*============================================================== 
destring gvkey, gen(gvkey_num)
xtset gvkey_num fyear

destring sic, gen(sic_num)
*egen ind_year=group(sic fyear) 

*==============================================================
* MERGE: FIRM AGE & HOBERG-PHILLIPS TNIC3 CLASSIFICATION
*==============================================================
merge 1:1 gvkey fyear using compustat_firmage_clean, keep(match master)
rename _merge merge_firmage

merge 1:1 gvkey_num fyear using tnic3, force keep(match master)
rename _merge merge_tnic3
*matched 53,778 observations only

merge 1:m gvkey fyear using nseg, keep (match master)
rename _merge merge_segments
*==============================================================
* Other Industry Classifications
*==============================================================

** Manufacturing Industries classification
gen mf=1 if sic_2dig>19 & sic_2dig<40
replace mf=0 if mf==.
label var mf "Indicator variable for Manufacturing industries"

** Technology Industries
gen tech=0
replace tech=1 if sic_3dig==357
replace tech=1 if  sic_3dig==366
replace tech=1 if sic_3dig==367
replace tech=1 if sic_3dig==382
replace tech=1 if sic_3dig==384
replace tech=1 if sic_3dig==481
replace tech=1 if sic_3dig==489
replace tech=1 if sic_3dig==737

** Industry Labels
gen industry=""
replace industry="Mining" if sic_2dig>=10 & sic_2dig<=14
replace industry="Construction" if sic_2dig>=15 & sic_2dig<=17
replace industry="Manufacturing" if sic_2dig>=20 & sic_2dig<=39
replace industry="Transportation, Eletric, Gas" if sic_2dig>=40 & sic_2dig<=49
replace industry="Wholesale Trade" if sic_2dig>=50 & sic_2dig<=51
replace industry="Retail Trade" if sic_2dig>=52 & sic_2dig<=59
replace industry="Finance, Insurance, Real Estate" if sic_2dig>=60 & sic_2dig<=67
replace industry="Services" if sic_2dig>=70 & sic_2dig<=89
replace industry="Public Administration" if sic_2dig>=91 & sic_2dig<=99

*==============================================================
* VARIABLE CREATION
*==============================================================

* load CPI scalor
ssc install cpigen, replace
cpigen

*1. Size measures
	gen CPI_at=at/cpi
	gen lnat=log(CPI_at)
	gen employees=emp*1000	

*2. Leverage
	gen leverage=(dlc+dltt)/(dlc+dltt+seq)

*3. Cash & Profitability measures 
	gen ROA=(ebitda/at)
	gen cash_holding = che/l.at

*4. Growth Measures
	*A. Tobin's Q
	gen Q=(at-ceq-txdb+(csho*prcc_f))/at

	*B. Sales growth	
	gen CPI_sale = sale/cpi
	gen sales_growth=(CPI_sale-l.CPI_sale)/l.CPI_sale
	
	*C R&D 
	gen rd=xrd/at
		gen rd_dummy = .
		replace rd_dummy = 1 if xrd != .
		replace rd_dummy = 0 if xrd == .
	
*5. Cost Measures
	gen scaled_cogs=cogs/sale
	gen scaled_sga=xsga/sale

*6. Financial Constraints & Probability of bankruptcy

	*A. Whited Wu Index
	gen CF=(ib+dp)/at
	gen DivPos=0
	replace DivPos=1 if dv>0 & dv !=.
	gen TLTD=dltt/at
	bysort sic fyear: egen ISG=mean(sales_growth)
	gen WW=-0.091*(CF)-.062*(DivPos)+(.021*TLTD)-.044*(log(CPI_at))+ ///
	.102*(ISG)-.035*(sales_growth)

	*B. Altman Z score
	gen z_score= 1.2*(wcap/at) + 1.4*(re/at) + 3.3*((oibdp-dp)/at) ///
	+ 0.6*((prcc_f*csho)/lt) + (sale/at)

dropmiss, force

*7. Lagging Variables
sort gvkey_num fyear

local lag_variables age csho nseg mkvalt prcc_f CPI_at CPI_sale ///
lnat leverage ROA Q rd rd_dummy sales_growth scaled_cogs scaled_sga employees cash_holding ///
WW z_score 

foreach var of varlist `lag_variables' {
gen lag_`var'   = l.`var'
}


*==============================================================
* WINSORIZE VARIABLES
*==============================================================
local win_variables age csho nseg mkvalt prcc_f CPI_at CPI_sale ///
lnat leverage ROA Q rd rd_dummy sales_growth scaled_cogs scaled_sga employees cash_holding ///
WW z_score lag_age lag_csho lag_nseg lag_mkvalt lag_prcc_f lag_CPI_at ///
lag_CPI_sale lag_lnat lag_leverage lag_ROA lag_Q lag_rd lag_rd_dummy lag_sales_growth ///
lag_scaled_cogs lag_scaled_sga lag_employees lag_cash_holding lag_WW lag_z_score

foreach var of varlist `win_variables' {
winsor `var', p(0.01) generate (win_`var')
}

*==============================================================
* Keeping only variables of interest
*==============================================================
keep gvkey gvkey_num cusip fyear sic sic_4dig sic_3dig sic_2dig sic_1dig ///
hp nseg mf tech industry win_age win_csho win_nseg win_mkvalt win_prcc_f ///
win_CPI_at win_CPI_sale win_lnat win_leverage win_ROA win_Q win_rd win_rd_dummy win_sales_growth ///
win_scaled_cogs win_scaled_sga win_employees win_cash_holding win_WW win_z_score ///
win_lag_age win_lag_csho win_lag_nseg win_lag_mkvalt win_lag_prcc_f ///
win_lag_CPI_at win_lag_CPI_sale win_lag_lnat win_lag_leverage win_lag_ROA ///
win_lag_Q win_lag_rd win_lag_rd_dummy win_lag_sales_growth win_lag_scaled_cogs win_lag_scaled_sga ///
win_lag_employees win_lag_cash_holding win_lag_WW win_lag_z_score

*==============================================================
* One last check for duplicates
*==============================================================

duplicates report cusip fyear
*No duplicates

duplicates list cusip fyear
duplicates drop cusip fyear, force
*Just to be sure

saveold compustat_data, replace
