*==============================================================
* Rival Growth Prospects & Equity Prices: Evidence from Layoffs
*==============================================================

* Authors: Bordeman, Kannan, Pinheiro
* Objective: Ensure layoff announcement is not contaminated by other events
* Data Sources: Compustat, CRSP, Eventus, Hoberg Phillips' TNIC classification, Factiva   


clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"
*This command allows me to access .dta files in my personal folder.


*==============================================================
* Set up
*==============================================================
use reshaped_layoff_data_sic3dig, clear

*==============================================================
* ALERT: DUPLICATES CHECK WITHIN AN SI1 CLUSTER
*==============================================================
gsort si1 -announcer
duplicates report si1 gvkey
duplicates drop si1 gvkey, force

*==============================================================
* Merge Winsorized Compustat Data
*==============================================================
destring sic, replace
merge m:1 gvkey fyear using compustat_data, keep (match)
rename _merge comp_merge
gsort si1-announcer


*==============================================================
* Merge Event Study data from Eventus
*==============================================================
compress
merge m:1 cusip_8dig announce_date using eventus_MAR_sr_sic, keep (match master)
drop _merge
*At this point, we matched 122,767 observations. Not matched 42,361 from master
drop if car_window_1==.
* Dropped 42,525


*==============================================================
* Creating Current S&P 500 indicator variable 
*==============================================================
*** FIRMS IN THE S&P 500 AT ANY TIME DURING 1980-2010
merge m:1 gvkey using sp500_ready_for_entry, keep(match master)
 drop _merge
replace sp500=0 if sp500==.

*** FIRMS CURRENTLY IN S&P 500 AT THE TIME OF ANNOUNCEMENT
merge m:1 gvkey using sp_index_ready, keep(match master)
	drop _merge
gen currently_sp=.

*A. Start with firms that were never in the S&P 500
	replace currently_sp=0 if from1==. 
*B. Then move to firms that were always in the S&P 500
	replace currently_sp=1 if announce_date>from1 & thru1==. & from2==. & from3==. & thru2==. & thru3==.
*C. Now firms that were in the S&P500 during the announcement date
	replace currently_sp=1 if announce_date>from1 & announce_date<thru1
*D. Now firms that entered the index after the announcement date
	replace currently_sp=0 if announce_date<from1
*E. Now firms that exit the index before the announcement date
	replace currently_sp=0 if announce_date<from1
	replace currently_sp=0 if announce_date>thru1 & from2==.
*F. Now firms in their second time in the index
	replace currently_sp=1 if announce_date>from2 & thru2==.
	replace currently_sp=1 if announce_date>from2 & announce_date<thru2
*G. Now firms kicked out of the index before the 2nd stint
	replace currently_sp=0 if announce_date>thru1 & announce_date<from2
	replace currently_sp=0 if announce_date>thru2 & from3==.
	replace currently_sp=0 if announce_date>thru2 & announce_date<from3
*H. Finally firms in their 3rd. stint in the index
	replace currently_sp=1 if announce_date>from3 & thru3==.
*I. There are two firms that the announcement date occurred exactly on the 
   *announcement date! they were not the announcers, but we may consider 
   *dropping the entire si1
	drop if si1==548
	drop if si1==1856

*=================================================================
* Merge Earnings, Dividends, Splits, Delisting, Exchange Datasets
*=================================================================
*1. Earnings announcements
	merge m:1 gvkey using earnings_data_rp, keep(match master)
	 drop _merge
	format announce_date %td
	gen earnings_dummy=0
	forvalues i = 1978(1)2014 {
	forvalues j = 1(1)4 {
	gen teste_`i'_Q`j'=announce_date - rdq_`i'_Q`j'
	replace earnings_dummy=1 if teste_`i'_Q`j'>=-5 & teste_`i'_Q`j'<=5
	drop teste_`i'_Q`j'
	}	
	}
	gen earnings_before_d=0
	forvalues i = 1978(1)2014 {
	forvalues j = 1(1)4 {
	gen teste_`i'_Q`j'=announce_date - rdq_`i'_Q`j'
	replace earnings_before_d=1 if teste_`i'_Q`j'>=-5 & teste_`i'_Q`j'<=0
	drop teste_`i'_Q`j'
	}	
	}
	drop rdq_*

*2. Dividend announcements	
	merge m:1 permno using dividend_ann, keep(match master)
	 drop _merge
	gen dividends_dummy=0
	forvalues j = 1(1)149 {
	gen teste_`j'=announce_date - dividend_ann_date`j'
	replace dividends_dummy=1 if teste_`j'>=-5 & teste_`j'<=5
	drop teste_`j'
	}
	drop dividend_ann_date*
	
*3. Stock split announcements	
	merge m:1 permno using split_ann, keep(match master)
	 drop _merge
	gen split_dummy=0
	forvalues j = 1(1)15 {
	gen teste_`j'=announce_date - split_ann_date`j'
	replace split_dummy=1 if teste_`j'>=-5 & teste_`j'<=5
	drop teste_`j'
	}
	drop split_ann_date*

*4. Delisting Data: THERE ARE LOTS OF DELISTING - MAINLY MERGERS AND DROPS
	merge m:1 permno using delisting_data, keep(match master)
	drop _merge
	merge m:1 permno using delisting_mergers, keep(match master)
	gen acquirer=0
	replace acquirer=1 if _merge==3
	 drop _merge
	tostring dlstcd, replace
	gen delisting = substr(dlstcd,1,1)
	label var delisting "Main delisting code"
	destring dlstcd, replace
	destring delisting, replace
*A. Acquisitions
	gen acquisition_before_ann_d=0
	forvalues j = 1(1)37 {
	gen dist_merger_ann`j' = announce_date - merge_date`j' if acquirer==1
	replace acquisition_before_ann_d=1 if dist_merger_ann`j'>=0 & dist_merger_ann`j'<=750
	drop dist_merger_ann`j'
	}
	rename acquisition_before_ann_d acquisition_past2yrs
	gen announcer_acquirer1=0
	replace announcer_acquirer1=1 if announcer==1 & acquisition_past2yrs==1
	bysort si1: egen announcer_acquirer=max(announcer_acquirer1)
	drop announcer_acquirer1
	label var announcer_acquirer "announcer made an acquisition in the past 2 years"
	drop merge_date*
*B. Now let's see how far delisting is from the announcement
	format dlstdt %td
	gen time_to_delisting = dlstdt-announce_date
	label var time_to_delisting "days from delisting date"
*C. First of all, let's get ride of firms that are about to delist
	gen about_delist=0
	replace about_delist=1 if time_to_delist <=180
*D. Now let's create a variable that indicates that delisting will occur within 2 years ****
    gen delisting_in2years=0
    replace delisting_in2years=1 if time_to_delisting<=730
    label var delisting_in2years " Dummy =1 if delisting within 2 years"
*E. Let's also break down in terms of dropped versus merger ***
    gen merger_in2years=0
    replace merger_in2years=1 if time_to_delisting<=730 & delisting==2
    replace merger_in2years=1 if time_to_delisting<=730 & delisting==3
    gen drop_in2years=0
    replace drop_in2years=1 if time_to_delisting<=730 & delisting==4
    replace drop_in2years=1 if time_to_delisting<=730 & delisting==5

*5. Eliminating announcements outside NYSE, AMEX, and NASDAQ 
	destring gvkey, replace
	merge m:1 gvkey fyear using stock_exchange_codes, keep(match master)
	drop _merge
*A. Dropping announcers	
	bysort si1: gen announcer_exchg1= exchg if announcer==1
	bysort si1: egen announcer_exchg = max(announcer_exchg1)
	 drop announcer_exchg1
	 drop if announcer_exchg<11 
	 drop if announcer_exchg>14
	 drop if announcer_exch==13
*B. Dropping competitors
	drop if exchg<11
	drop if exchg>14
	drop if exchg==13
*C. Creating varibale if announcer & competitor are in the same exchange
	gen same_exchange=0
	replace same_exchange=1 if exchg==announcer_exchg
  	
*6. Delisting rules: Drop observations that are not in the main exchanges
	merge m:1 permno announce_date using delisting_rules, keep(match master)
	 drop _merge
	 drop if exchcd<=0
	 drop if exchcd>3
     drop if delisted_nasdaq==1



*=================================================================
* VARIABLE CREATION
*=================================================================

*1. Good & Bad News Indicators
	gen positive_car_window_1 =.
	 replace positive_car_window_1 =1 if car_window_1>0
	 replace positive_car_window_1=0 if car_window_1<=0
	gen positive_CAR_announcer_ann=.
	 replace positive_CAR_announcer_ann=1 if positive_car_window_1 ==1 & announcer==1
	 replace positive_CAR_announcer_ann=0 if positive_car_window_1 ==0 & announcer==1
	gsort si1 -announcer
	by si1: replace positive_CAR_announcer_ann=positive_CAR_announcer_ann[_n-1] if announcer==0

*2. Layoff Ratio: laid off size to total employees of announcer
	gen layoffratio=.
	replace layoffratio=size/win_lag_employees if announcer==1
	gsort si1 -announcer
	by si1: replace layoffratio=layoffratio[_n-1] if layoffratio==. & announcer==0
    drop if layoffratio == .

*3. Hirschman-herfindahl index
	bysort si1: egen total_sales = sum(win_lag_CPI_sale)
	gen market_share = win_lag_CPI_sale/total_sales
	egen mkt_share_group = pctile(market_share), by(si1) p(95) 
	gen market_share_2=market_share^2
	by si1: egen lag_HHI=sum(market_share_2)
	 drop total_sales market_share market_share_2
	winsor lag_HHI, p(0.01) gen(win_lag_HHI)
	
*4. Time Indicators
	gen decade=.
	 replace decade=1 if fyear>=1980 & fyear<1990
	 replace decade=2 if fyear>=1990 & fyear<2000
	 replace decade=3 if fyear>=2000
	gen decade2=0
	 replace decade2=1 if decade==2
	gen decade3=0
     replace decade3 = 1 if decade==3
    tab decade
	gen yearann = year(announce_date)
	label var yearann "year of announcement"
	
	
*5. Variables for Time between Layoffs	

saveold layoff_temp_for_distance, replace

* Creating a file for the number of layoffs by a firm
clear all
set more off
capture log close
set logtype text
cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"

use layoff_temp_for_distance, clear
keep if announcer==1
keep gvkey announce_date
sort gvkey announce_date
by gvkey: gen j = _n
rename announce_date layoff_time
reshape wide layoff_time, i(gvkey) j(j)
saveold layoff_times_Bharad, replace

* Creating a file for the distance between layoffs
clear all
set more off
capture log close
set logtype text
cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"

use layoff_temp_for_distance, clear
keep if announcer==1
keep gvkey announce_date
format announce_date %td
sort gvkey announce_date
by gvkey: gen days_prev_ann = announce_date[_n] - announce_date[_n-1]
gen within_100days =0
replace within_100days=1 if days_prev_ann<=100

saveold distance_ann_Bharad.dta, replace

stop;
********************************************************************************
*				 RUN STEP 3B, then compile rest of the code					   *
********************************************************************************

use layoff_temp_for_distance, clear
***	Merging distance between announcements by announcer
	merge m:m gvkey announce_date using distance_ann_Bharad, keep(match master)
	drop _merge
*A. Are layoffs by a firm within 100 days of each other?
	bysort si1: egen within_100days1 = max(within_100days)
	drop within_100days
	rename within_100days1 within_100days	

*6. Variables related to Event Study

*A. Assigning announcer CAR to all competitors within si1
	gsort si1-announcer
	by si1: gen announcer_car_window_1=car_window_1 if announcer==1
	by si1: replace announcer_car_window_1=announcer_car_window_1[_n-1] if announcer!=1	

*B. Assigning positive announcer CAR dummy to all competitors within si1
	bysort si1: egen positive_CAR_announcer=max(positive_CAR_announcer_ann)
	label var positive_CAR_announcer "Positive Announcer 3-day CAR, Indicator Variable"
	sum car_window_1 if announcer==0, detail
	sum car_window_1 if announcer==1, detail

*C. Revising variable definition that describes R&D expenditure
	
	gen win_lag_rd_complete = win_lag_rd
	 replace win_lag_rd_complete = 0 if win_lag_rd == .
	gen missing_rd = 0
	replace missing_rd = 1 if win_lag_rd == .
	label var missing_rd "No R\&D data"

*8. Segment data variables
	bysort si1: gen announcer_nseg1=nseg if announcer==1
	bysort si1: egen announcer_nseg=max(announcer_nseg1)
	gen dist_ann_nseg=nseg-announcer_nseg
	 drop announcer_nseg1
	 label var dist_ann_nseg "# of segments relative to announcer"
	gen abs_dist_ann_nseg = abs(dist_ann_nseg)

*9. Eliminating small layoffs
	replace si1=. if size<50
    *1,252 real changes made, 1,252 to missing
    drop if si1==.
    *1,252 observations deleted


*==============================================================
* Labeling key variables
*==============================================================

label var permanent_rif "Permanent Reduction in Force, Indicator variable"
label var layoff "Fired, Indicator variable"
label var m_a "M&A"
label var restructuring "Restructuring"
label var plant_closing "Plant Closing"
label var demand_slump "Demand Slump"
label var sales "Sales Slump"
label var cost_and_profitability "Cost Cutting or Increased Profitability"
label var other "Other Layoff Reason"
label var market_competition "Increased Market Competition"
label var efficiency "Efficiency"
label var no_reason "No Stated Reason"
label var layoffratio "Ratio of layoff size to total employment"
label var win_lag_Q "Q, winsorized and lagged Kaplan Zingales"
label var win_lag_CPI_sale "Sales, winsorized and lagged"
label var win_lag_leverage "Leverage, winsorized and lagged"
label var win_lag_ROA "ROA, winsorized and lagged"
label var win_lag_WW "Whited Wu Index, winsorized and lagged"


saveold ready_for_analysis_MAR, replace


