*==============================================================
* Rival Growth Prospects & Equity Prices: Evidence from Layoffs
*==============================================================

* Authors: Bordeman, Kannan, Pinheiro
* Objective: Create primary sample with complete data for main tests
* Data Sources: Compustat, CRSP, Eventus, Hoberg Phillips' TNIC classification, Factiva   


clear all
set more off
capture log close
set logtype text

cd "/Users/bkannan/Dropbox/Research/Contagion effects of layoffs/BKP codes and data/Data"
*This command allows me to access .dta files in my personal folder.

*==============================================================
* SET UP
*==============================================================


use ready_for_analysis_MAR.dta, clear

*==============================================================
* Merging in Simple modified HHI data
*==============================================================

tostring sic_3dig, replace
merge m:m sic_3dig fyear using SMHHI_sic_v2.dta
drop if _merge==2
drop _merge

destring sic_3dig, replace

*==============================================================
*	Indicator variables for sample cuts
*==============================================================
*1. Indicator variable for high and low concentration based on median
	gen high_HHI=0
	codebook lag_HHI
	replace high_HHI=1 if lag_HHI >= .084163

*==============================================================
*	Making sure we have a Complete Sample
*==============================================================

*** Check for extreme layoffs. There is one quite extreme layoff in which the 
  * announcer gets a positive CAR of 0.66 - second highest is 0.26. Let's 
  * highlight this case and it's competitors
	gen extreme=0
	replace extreme=1 if announcer==1 & car_window_1>0.3
	codebook si1 if extreme==1
	replace extreme=1 if si1==1681

*1. Ensuring sample has no missing data for independent variables 
	gen sample=1
	 replace sample=0 if announcer == 1 & car_window_1 == .
	 replace sample=0 if announcer == 0 & win_lag_Q == .
	 replace sample=0 if win_lag_age==. | win_lag_lnat==. | win_lag_cash_holding==. ///
	 | win_lag_ROA==. | win_lag_sales_growth==. | win_lag_emp==. | win_lag_leverage==. ///
	 | win_lag_rd_complete==. | nseg==. | currently_sp==. | win_z_score==. ///
	 | win_lag_scaled_cogs==. | win_lag_scaled_sga==.

*2. Here we are eliminating annoucers without competitors
	bysort si1: egen teste2 = min(announcer) if sample==1
  * There are announcers with no competitors. Let's avoid this cases;
	gen sample_all=0
	replace sample_all=1 if sample==1 & teste2==0
	drop teste2

*3. Here we are eliminating competitors without announcers 
	gen sample_all_restrict=0
	bysort si1: egen teste3=max(announcer) if sample_all==1
	replace sample_all_restrict=1 if sample_all==1 & teste3==1
	drop teste3

*4. Imposing earnings, dividends, stock splits & other restrictions
    * Earnings
	bysort si1: gen announcer_earnings1=earnings_dummy if announcer==1
	bysort si1: egen announcer_earnings=max(announcer_earnings1)
	 drop announcer_earnings1
    * Dividends
	bysort si1: gen announcer_dividends1=dividends_dummy if announcer==1
	bysort si1: egen announcer_dividends=max(announcer_dividends1)
	 drop announcer_dividends1
    * Stock splits
	bysort si1: gen announcer_split1=split_dummy if announcer==1
	bysort si1: egen announcer_split=max(announcer_split1)
	 drop announcer_split1
    * Above 3 and other restrictions
	gen sample_all_restrict_new = sample_all_restrict
	replace sample_all_restrict_new=0 if announcer_earnings==1
	replace sample_all_restrict_new=0 if announcer_dividends==1
	replace sample_all_restrict_new=0 if announcer_split==1
	replace sample_all_restrict_new=0 if earnings_dummy==1
	replace sample_all_restrict_new=0 if dividends_dummy==1
	replace sample_all_restrict_new=0 if split_dummy==1
	replace sample_all_restrict_new=0 if about_delist==1
	replace sample_all_restrict_new=0 if part_of_previous_announcement==1
	replace sample_all_restrict_new=0 if within_100days==1

*5  Variable to indicate that the announcer is currently in the S&P 500 index
	gen announcer_sp1=.
	 replace announcer_sp1=1 if announcer==1 & currently_sp==1
	bysort si1: egen announcer_sp=max(announcer_sp1)
	 drop announcer_sp1
	 label var announcer_sp "=1 if announcer currently a member of the S&P500 index"

*6. Now again cleaning announcements by firms with no competitors in the sample:
	bysort si1: egen teste2 = min(announcer) if extreme==0 & sample_all_restrict_new==1 & announcer_sp==1
	gen test4=0
     replace test4=1 if extreme==0 & sample_all_restrict_new==1 & announcer_sp==1 & teste2==0
	 replace sample_all_restrict_new=0 if test4==0
	 drop teste2 test4
	 
codebook announcer if sample_all_restrict_new==1



*==============================================================
* Cases where CAR is Statistically different from zero
*==============================================================

*	First Looking at announcers
*1. 2.5% on each tail 
	gen ann_test_significance_95_tt1=0
	 replace ann_test_significance_95_tt1=1 if scar1<=-1.96 & announcer==1
	 replace ann_test_significance_95_tt1=1 if scar1>=1.96 & announcer==1
	bysort si1: egen ann_test_significance_95_tt=max(ann_test_significance_95_tt1)

*2. 5% on each tail 
	gen ann_test_significance_90_tt1=0
	 replace ann_test_significance_90_tt1=1 if scar1<=-1.645 & announcer==1
	 replace ann_test_significance_90_tt1=1 if scar1>=1.645 & announcer==1
	bysort si1: egen ann_test_significance_90_tt=max(ann_test_significance_90_tt1)

*   Then, looking at competitors' reactions 
*1. 2.5% on each tail
	gen comp_test_significance_95_tt=0
	 replace comp_test_significance_95_tt=. if announcer==1
	 replace  comp_test_significance_95_tt=1 if scar1<=-1.96 & announcer==0
	 replace  comp_test_significance_95_tt=1 if scar1>=1.96 & announcer==0
*2. 5% on each tail 
	gen comp_test_significance_90_tt=0
	 replace comp_test_significance_90_tt=. if announcer==1
	 replace  comp_test_significance_90_tt=1 if scar1<=-1.645 & announcer==0
	 replace  comp_test_significance_90_tt=1 if scar1>=1.645 & announcer==0

codebook comp_test_significance_95_tt if ann_test_significance_95_tt==1 & announcer==0


*==============================================================
* Key Dependent Variables
*==============================================================
* some additional variables

gen car_window_1_percent = car_window_1*100
 winsor car_window_1_percent,  p(0.01) generate (win_car_window_1_percent)
gen car_window_4_percent = car_window_4*100
gen car_window_5_percent = car_window_5*100
gen announcer_CAR_percent = announcer_car_window_1*100

gen no_RD=0
 replace no_RD=1 if win_lag_rd == .
gen RD=(1-no_RD) 


*==============================================================
* Creating a variables for Random effects Analysis
*==============================================================
global testvars win_lag_Q RD win_lag_sales_growth ///
		        win_lag_leverage win_lag_WW win_lag_z_score ///
				win_lag_ROA win_lag_cash_holding ///
				win_lag_lnat win_lag_age win_lag_employees  ///
	            win_lag_scaled_cogs win_lag_scaled_sga nseg currently_sp
 
foreach var of varlist $testvars  {
bysort si1: egen `var'_mean = mean(`var') if announcer==0 & extreme==0 & sample_all_restrict_new==1  & announcer_sp==1
}
global announcevars win_lag_Q RD win_lag_sales_growth ///
		          win_lag_leverage win_lag_WW win_lag_z_score ///
				  win_lag_ROA win_lag_cash_holding ///
				  win_lag_lnat win_lag_age win_lag_employees  ///
	              win_lag_scaled_cogs win_lag_scaled_sga nseg currently_sp
				  
foreach var of varlist $announcevars {
gen ann_`var'1 = `var' if announcer==1 & extreme==0 & sample_all_restrict_new==1  & announcer_sp==1
bysort si1: egen ann_`var' = max(ann_`var'1)
drop ann_`var'1
}
		  
label var win_lag_Q_mean "Average Q"
label var RD_mean "Average R\&D"
label var win_lag_sales_growth_mean "Average Sales Growth"
label var win_lag_ROA_mean "Average ROA"
label var win_lag_leverage_mean "Average Leverage"
label var win_lag_cash_holding_mean "Average Cash Holdings"
label var win_lag_lnat_mean "Average Log(Total Assets)"
label var win_lag_employees_mean "Average No. of Employees"
label var nseg_mean "Average No. of Segments"
label var win_lag_scaled_cogs_mean "Average COGS"
label var win_lag_scaled_sga_mean "Average SG/&A"
label var win_lag_employees "No. of Employees"
label var no_RD "No R\&D "
label var currently_sp "S\&P 500"
label var nseg "No. of Segments"
label var car_window_1_percent "CAR[-1,+1]"
label var car_window_4_percent "CAR[-2,+2]"
label var car_window_5_percent "CAR[-5,+5]"
label var announcer_CAR_percent "Announcer CAR[-1,+1]"
label var win_lag_leverage "Leverage"
label var win_lag_lnat "log(Total Assets)"
label var win_lag_Q "Tobin's Q"
label var win_lag_age "Age"
label var win_lag_cash_holding "Cash Holdings"
label var win_lag_sales_growth "Sales Growth"
label var win_lag_ROA "RoA"
label var RD "R\&D"
label var win_lag_scaled_cogs "COGS"
label var win_lag_scaled_sga "SG\&A"
label var win_lag_z_score "Altman's Z-score"
label var win_lag_WW "Whited Wu Index"
label var car_window_1_percent "CAR[-1,+1]"
label var win_lag_leverage "Leverage"
label var win_lag_lnat "log(Total Assets)"
label var win_lag_age "Age"
label var win_lag_cash_holding "Cash Holdings"
label var win_lag_sales_growth "Sales Growth"
label var win_lag_rd_complete "R\&D"
label var win_lag_ROA "RoA"
label var size "Layoff Size"
label var layoffratio "Layoff Ratio"

saveold ready_for_tables, replace

	
